@@ -73,6 +73,8 @@ describe 'ceilometer::agent::polling' do
       it { should contain_ceilometer_config('polling/batch_size').with_value('<SERVICE DEFAULT>') }
       it { should_not contain_file('polling') }
       it { should contain_ceilometer_config('polling/tenant_name_discovery').with_value('<SERVICE DEFAULT>') }
+      it { should contain_ceilometer_config('polling/pollsters_definitions_dirs').with_value('<SERVICE DEFAULT>') }
+      it { should contain_ceilometer_config('polling/cfg_file').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'when setting package_ensure' do
@@ -113,6 +115,19 @@ describe 'ceilometer::agent::polling' do
       }
     end
 
+    context 'when pollsters_definitions_dirs is set' do
+      before do
+        params.merge!(
+          :pollsters_definitions_dirs => ['/etc/ceilometer/pollsters.d', '/etc/ceilometer/mypollsters.d']
+        )
+      end
+
+      it {
+        should contain_ceilometer_config('polling/pollsters_definitions_dirs').with_value(
+          '/etc/ceilometer/pollsters.d,/etc/ceilometer/mypollsters.d')
+      }
+    end
+
     context 'with compute namespace disabled' do
       before do
         params.merge!(
@@ -197,7 +212,7 @@ describe 'ceilometer::agent::polling' do
         :content                 => '---
 sources:
     - name: some_pollsters
-      interval: 600
+      interval: 300
       meters:
         - cpu
         - cpu_l3_cache
@@ -217,6 +232,7 @@ sources:
         :selinux_ignore_defaults => true,
         :tag                     => 'ceilometer-yamls',
       )}
+      it { should contain_ceilometer_config('polling/cfg_file').with_value('/etc/ceilometer/polling.yaml') }
     end
 
     context 'with polling and basic custom settings' do
@@ -240,6 +256,7 @@ sources:
         :selinux_ignore_defaults => true,
         :tag                     => 'ceilometer-yamls',
       )}
+      it { should contain_ceilometer_config('polling/cfg_file').with_value('/etc/ceilometer/polling.yaml') }
     end
 
     context 'with polling and custom config' do
@@ -269,6 +286,7 @@ sources:
   - meterbar
 ',
       )}
+      it { should contain_ceilometer_config('polling/cfg_file').with_value('/etc/ceilometer/polling.yaml') }
     end
 
     context 'with polling management disabled' do
@@ -277,6 +295,7 @@ sources:
       end
 
       it { should_not contain_file('polling') }
+      it { should contain_ceilometer_config('polling/cfg_file').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'when batch_size is set' do
