@@ -23,18 +23,6 @@ describe 'ceilometer::config' do
     end
   end
 
-  shared_examples_for 'ceilometer_api_paste_ini' do
-    let :params do
-      { :ceilometer_api_paste_ini => config_hash }
-    end
-
-    it 'configures arbitrary ceilometer-api-paste-ini configurations' do
-      is_expected.to contain_ceilometer_api_paste_ini('DEFAULT/foo').with_value('fooValue')
-      is_expected.to contain_ceilometer_api_paste_ini('DEFAULT/bar').with_value('barValue')
-      is_expected.to contain_ceilometer_api_paste_ini('DEFAULT/baz').with_ensure('absent')
-    end
-  end
-
   on_supported_os({
     :supported_os   => OSDefaults.get_supported_os
   }).each do |os,facts|
@@ -44,7 +32,6 @@ describe 'ceilometer::config' do
       end
 
       it_configures 'ceilometer_config'
-      it_configures 'ceilometer_api_paste_ini'
     end
   end
 end
