@@ -46,13 +46,7 @@ describe 'ceilometer' do
         it_configures 'rabbit with SSL support'
         it_configures 'rabbit without HA support'
       end
-
     end
-
-    context 'with amqp messaging' do
-      it_configures 'amqp support'
-    end
-
   end
 
   shared_examples_for 'a ceilometer base installation' do
@@ -95,7 +89,8 @@ describe 'ceilometer' do
       is_expected.to contain_oslo__messaging__notifications('ceilometer_config').with(
         :transport_url => '<SERVICE DEFAULT>',
         :driver        => '<SERVICE DEFAULT>',
-        :topics        => ['notifications']
+        :topics        => '<SERVICE DEFAULT>',
+        :retry         => '<SERVICE DEFAULT>',
       )
     end
 
@@ -130,6 +125,7 @@ describe 'ceilometer' do
           :notification_topics        => ['notifications', 'custom'],
           :notification_driver        => 'messagingv2',
           :notification_transport_url => 'rabbit://rabbit_user:password@localhost:5673',
+          :notification_retry         => 10,
         )
       }
 
@@ -137,7 +133,8 @@ describe 'ceilometer' do
         is_expected.to contain_oslo__messaging__notifications('ceilometer_config').with(
           :transport_url => 'rabbit://rabbit_user:password@localhost:5673',
           :driver        => 'messagingv2',
-          :topics        => ['notifications', 'custom']
+          :topics        => ['notifications', 'custom'],
+          :retry         => 10,
         )
       end
     end
@@ -161,6 +158,7 @@ describe 'ceilometer' do
         :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+        :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
       )
     end
 
@@ -239,56 +237,6 @@ describe 'ceilometer' do
     end
   end
 
-  shared_examples_for 'amqp support' do
-    context 'with default parameters' do
-      it { is_expected.to contain_oslo__messaging__amqp('ceilometer_config').with(
-        :server_request_prefix => '<SERVICE DEFAULT>',
-        :broadcast_prefix      => '<SERVICE DEFAULT>',
-        :group_request_prefix  => '<SERVICE DEFAULT>',
-        :container_name        => '<SERVICE DEFAULT>',
-        :idle_timeout          => '<SERVICE DEFAULT>',
-        :trace                 => '<SERVICE DEFAULT>',
-        :ssl_ca_file           => '<SERVICE DEFAULT>',
-        :ssl_cert_file         => '<SERVICE DEFAULT>',
-        :ssl_key_file          => '<SERVICE DEFAULT>',
-        :sasl_mechanisms       => '<SERVICE DEFAULT>',
-        :sasl_config_dir       => '<SERVICE DEFAULT>',
-        :sasl_config_name      => '<SERVICE DEFAULT>',
-        :username              => '<SERVICE DEFAULT>',
-        :password              => '<SERVICE DEFAULT>',
-      ) }
-    end
-
-    context 'with overridden amqp parameters' do
-      before { params.merge!(
-        :amqp_idle_timeout  => '60',
-        :amqp_trace         => true,
-        :amqp_ssl_ca_file   => '/path/to/ca.cert',
-        :amqp_ssl_cert_file => '/path/to/certfile',
-        :amqp_ssl_key_file  => '/path/to/key',
-        :amqp_username      => 'amqp_user',
-        :amqp_password      => 'password',
-      ) }
-
-      it { is_expected.to contain_oslo__messaging__amqp('ceilometer_config').with(
-        :server_request_prefix => '<SERVICE DEFAULT>',
-        :broadcast_prefix      => '<SERVICE DEFAULT>',
-        :group_request_prefix  => '<SERVICE DEFAULT>',
-        :container_name        => '<SERVICE DEFAULT>',
-        :idle_timeout          => '60',
-        :trace                 => true,
-        :ssl_ca_file           => '/path/to/ca.cert',
-        :ssl_cert_file         => '/path/to/certfile',
-        :ssl_key_file          => '/path/to/key',
-        :sasl_mechanisms       => '<SERVICE DEFAULT>',
-        :sasl_config_dir       => '<SERVICE DEFAULT>',
-        :sasl_config_name      => '<SERVICE DEFAULT>',
-        :username              => 'amqp_user',
-        :password              => 'password',
-      ) }
-    end
-  end
-
   on_supported_os({
     :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
